[Libreoffice-commits] core.git: 2 commits - chart2/source cui/source cui/uiconfig external/np_sdk filter/qa filter/source fpicker/source framework/inc framework/qa framework/source include/basic include/registry include/svx odk/examples offapi/com offapi/type_reference qadevOOo/tests scripting/examples sc/source sd/source sfx2/source shell/source starmath/inc svgio/source svtools/source svx/source swext/mediawiki sw/inc sw/qa sw/source test/source vcl/source writerfilter/source

Julien Nabet serval2412 at yahoo.fr
Wed Mar 25 13:13:00 PDT 2015


 chart2/source/tools/InternalDataProvider.cxx                                  |    6 ++---
 cui/source/tabpages/numfmt.cxx                                                |    2 -
 cui/uiconfig/ui/numberingformatpage.ui                                        |    4 +--
 external/np_sdk/inc/npfunctions.h                                             |    4 +--
 external/np_sdk/npsdk/npupp.h                                                 |    4 +--
 filter/qa/complex/filter/misc/FinalizedMandatoryTest.java                     |    2 -
 filter/source/xslt/import/uof/uof2odf_spreadsheet.xsl                         |    8 +++---
 filter/source/xslt/odf2xhtml/export/xhtml/body.xsl                            |    2 -
 fpicker/source/win32/filepicker/PreviewCtrl.hxx                               |    2 -
 framework/inc/classes/filtercachedata.hxx                                     |    6 ++---
 framework/qa/complex/framework/autosave/Protocol.java                         |    4 +--
 framework/source/accelerators/keymapping.cxx                                  |    2 -
 framework/source/fwi/classes/converter.cxx                                    |   12 +++++-----
 framework/source/jobs/jobdata.cxx                                             |    2 -
 framework/source/jobs/joburl.cxx                                              |    2 -
 framework/source/xml/acceleratorconfigurationreader.cxx                       |    2 -
 include/basic/sbxform.hxx                                                     |    2 -
 include/registry/types.h                                                      |    2 -
 include/svx/DescriptionGenerator.hxx                                          |    8 +++---
 odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/FunctionHelper.java |    2 -
 odk/examples/java/Text/HardFormatting.java                                    |    8 +++---
 offapi/com/sun/star/text/DateDisplayFormat.idl                                |    2 -
 offapi/com/sun/star/text/TimeDisplayFormat.idl                                |    2 -
 offapi/com/sun/star/text/textfield/URL.idl                                    |    2 -
 offapi/type_reference/typelibrary_history.txt                                 |    4 +--
 qadevOOo/tests/java/ifc/inspection/_XObjectInspectorModel.java                |    2 -
 qadevOOo/tests/java/ifc/style/_CharacterProperties.java                       |    2 -
 sc/source/ui/view/viewdata.cxx                                                |    2 -
 scripting/examples/java/Newsgroup/PostNewsgroup.java                          |    2 -
 sd/source/ui/app/sdmod2.cxx                                                   |    2 -
 sd/source/ui/inc/taskpane/TaskPaneTreeNode.hxx                                |    2 -
 sfx2/source/bastyp/fltfnc.cxx                                                 |    2 -
 shell/source/win32/shlxthandler/infotips/infotips.cxx                         |    2 -
 starmath/inc/cursor.hxx                                                       |    2 -
 svgio/source/svgreader/svgtextpathnode.cxx                                    |    2 -
 svtools/source/control/fmtfield.cxx                                           |    2 -
 svx/source/svdraw/svdotextdecomposition.cxx                                   |    2 -
 sw/inc/IDocumentContentOperations.hxx                                         |    4 +--
 sw/inc/dbfld.hxx                                                              |    2 -
 sw/inc/doc.hxx                                                                |    2 -
 sw/inc/fesh.hxx                                                               |    2 -
 sw/inc/fldbas.hxx                                                             |    2 -
 sw/inc/node.hxx                                                               |    2 -
 sw/inc/swtable.hxx                                                            |    2 -
 sw/qa/extras/tiledrendering/tiledrendering.cxx                                |    2 -
 sw/source/core/crsr/crsrsh.cxx                                                |    2 -
 sw/source/core/edit/edlingu.cxx                                               |    4 +--
 sw/source/core/layout/trvlfrm.cxx                                             |    2 -
 sw/source/core/text/widorp.cxx                                                |    2 -
 sw/source/filter/ww8/ww8par3.cxx                                              |    2 -
 swext/mediawiki/src/filter/odt2mediawiki.xsl                                  |    2 -
 test/source/sheet/xnamedrange.cxx                                             |    2 -
 vcl/source/app/scheduler.cxx                                                  |    2 -
 vcl/source/edit/textdata.cxx                                                  |    4 +--
 vcl/source/filter/sgvtext.cxx                                                 |    2 -
 writerfilter/source/dmapper/StyleSheetTable.cxx                               |    2 -
 56 files changed, 82 insertions(+), 82 deletions(-)

New commits:
commit 25d3c618d831036c08194610f188e4781c135cfc
Author: Julien Nabet <serval2412 at yahoo.fr>
Date:   Wed Mar 25 21:12:16 2015 +0100

    Typo: formated->formatted
    
    Change-Id: Iefd4d375a0dfb36732233852f906c6b85dccc2a5

diff --git a/cui/source/tabpages/numfmt.cxx b/cui/source/tabpages/numfmt.cxx
index 8fdcb7e..04c8e6e 100644
--- a/cui/source/tabpages/numfmt.cxx
+++ b/cui/source/tabpages/numfmt.cxx
@@ -265,7 +265,7 @@ SvxNumberFormatTabPage::SvxNumberFormatTabPage(vcl::Window* pParent,
     get(m_pEdLeadZeroes, "leadzerosed");
     get(m_pBtnThousand, "thousands");
     get(m_pFormatCodeFrame, "formatcode");
-    get(m_pEdFormat, "formated");
+    get(m_pEdFormat, "formatted");
     get(m_pIbAdd, "add");
     get(m_pIbInfo, "edit");
     get(m_pIbRemove, "delete");
diff --git a/cui/uiconfig/ui/numberingformatpage.ui b/cui/uiconfig/ui/numberingformatpage.ui
index e6e751d..b7be2e1 100644
--- a/cui/uiconfig/ui/numberingformatpage.ui
+++ b/cui/uiconfig/ui/numberingformatpage.ui
@@ -100,7 +100,7 @@
                 <property name="row_spacing">6</property>
                 <property name="column_spacing">6</property>
                 <child>
-                  <object class="GtkEntry" id="formated">
+                  <object class="GtkEntry" id="formatted">
                     <property name="visible">True</property>
                     <property name="can_focus">True</property>
                     <property name="valign">center</property>
@@ -194,7 +194,7 @@
             <property name="can_focus">False</property>
             <property name="label" translatable="yes">_Format code</property>
             <property name="use_underline">True</property>
-            <property name="mnemonic_widget">formated</property>
+            <property name="mnemonic_widget">formatted</property>
             <attributes>
               <attribute name="weight" value="bold"/>
             </attributes>
diff --git a/external/np_sdk/inc/npfunctions.h b/external/np_sdk/inc/npfunctions.h
index 9754567..0d3a662 100644
--- a/external/np_sdk/inc/npfunctions.h
+++ b/external/np_sdk/inc/npfunctions.h
@@ -227,8 +227,8 @@ enum
 typedef struct _BPSupportedMIMETypes
 {
  SInt32    structVersion;      /* struct version */
- Handle    typeStrings;        /* STR# formated handle, allocated by plug-in */
- Handle    infoStrings;        /* STR# formated handle, allocated by plug-in */
+ Handle    typeStrings;        /* STR# formatted handle, allocated by plug-in */
+ Handle    infoStrings;        /* STR# formatted handle, allocated by plug-in */
 } BPSupportedMIMETypes;
 OSErr BP_GetSupportedMIMETypes(BPSupportedMIMETypes *mimeInfo, UInt32 flags);
 #define NP_GETMIMEDESCRIPTION_NAME "NP_GetMIMEDescription"
diff --git a/external/np_sdk/npsdk/npupp.h b/external/np_sdk/npsdk/npupp.h
index e0812ec..e21475a 100644
--- a/external/np_sdk/npsdk/npupp.h
+++ b/external/np_sdk/npsdk/npupp.h
@@ -1180,8 +1180,8 @@ enum
 typedef struct _BPSupportedMIMETypes
 {
  SInt32    structVersion;      // struct version
- Handle    typeStrings;        // STR# formated handle, allocated by plug-in
- Handle    infoStrings;        // STR# formated handle, allocated by plug-in
+ Handle    typeStrings;        // STR# formatted handle, allocated by plug-in
+ Handle    infoStrings;        // STR# formatted handle, allocated by plug-in
 } BPSupportedMIMETypes;
 OSErr BP_GetSupportedMIMETypes(BPSupportedMIMETypes *mimeInfo, UInt32 flags);
 
diff --git a/filter/source/xslt/odf2xhtml/export/xhtml/body.xsl b/filter/source/xslt/odf2xhtml/export/xhtml/body.xsl
index d591bbf..8a3e701 100644
--- a/filter/source/xslt/odf2xhtml/export/xhtml/body.xsl
+++ b/filter/source/xslt/odf2xhtml/export/xhtml/body.xsl
@@ -2006,7 +2006,7 @@
 									</xsl:variable>
 									<!-- Numbering is being done by this transformation creating a HTML span representing the number label
 										 The html:span represents the list item/header label (e.g. 1.A.III)
-										 As the html:span is usually a inline element is formated by CSS as block element to use width upon it,
+										 As the html:span is usually a inline element is formatted by CSS as block element to use width upon it,
 										 to disable the caridge return float:left is used and later neglected -->
 									<xsl:element name="span">
 										<xsl:if test="$listLevelStyle/@text:style-name">
diff --git a/framework/inc/classes/filtercachedata.hxx b/framework/inc/classes/filtercachedata.hxx
index 7bb3d24..d141652 100644
--- a/framework/inc/classes/filtercachedata.hxx
+++ b/framework/inc/classes/filtercachedata.hxx
@@ -580,13 +580,13 @@ class FilterCFGAccess : public ::utl::ConfigItem
         void                        write           (       DataContainer&   rData                                  ,
                                                             DataContainer::ECFGType         eType                   ); // write values from given struct to configuration
 
-        static   OUString    encodeTypeData  ( const FileType&        aType                                  ); // build own formated string of type properties
+        static   OUString    encodeTypeData  ( const FileType&        aType                                  ); // build own formatted string of type properties
         static   void               decodeTypeData  ( const OUString& sData                                  ,
                                                             FileType&        aType                                  );
-        static   OUString    encodeFilterData( const Filter&          aFilter                                ); // build own formated string of filter properties
+        static   OUString    encodeFilterData( const Filter&          aFilter                                ); // build own formatted string of filter properties
         static   void               decodeFilterData( const OUString& sData                                  ,
                                                             Filter&          aFilter                                );
-        static   OUString    encodeStringList( const OUStringList&    lList                                  ); // build own formated string of OUStringList
+        static   OUString    encodeStringList( const OUStringList&    lList                                  ); // build own formatted string of OUStringList
         static   OUStringList       decodeStringList( const OUString& sValue                                 );
 
         void             setProductName                             (       OUStringHashMap&                                       lUINames        );
diff --git a/framework/qa/complex/framework/autosave/Protocol.java b/framework/qa/complex/framework/autosave/Protocol.java
index 6748fc3..76f64b2 100644
--- a/framework/qa/complex/framework/autosave/Protocol.java
+++ b/framework/qa/complex/framework/autosave/Protocol.java
@@ -405,7 +405,7 @@ public class Protocol extends JComponent
         }
 
         /**
-         * create a colored table cell formated as HTML.
+         * create a colored table cell formatted as HTML.
          *
          * @param   sCell
          *          an outside string buffer, which can be
@@ -662,7 +662,7 @@ public class Protocol extends JComponent
     /**
      * returns a generic html header for generating html log files
      *
-     * It's used from the method finish() to generate a valid html formated file.
+     * It's used from the method finish() to generate a valid html formatted file.
      * For that its necessary to open some special html targets like e.g. <html>.
      *
      * @return  A string, which includes the whole header.
diff --git a/framework/source/accelerators/keymapping.cxx b/framework/source/accelerators/keymapping.cxx
index 03d0189..6b096a8 100644
--- a/framework/source/accelerators/keymapping.cxx
+++ b/framework/source/accelerators/keymapping.cxx
@@ -165,7 +165,7 @@ sal_uInt16 KeyMapping::mapIdentifierToCode(const OUString& sIdentifier)
     if (pIt != m_lIdentifierHash.end())
         return pIt->second;
 
-    // Its not well known identifier - but may be a pure key code formated as string ...
+    // Its not well known identifier - but may be a pure key code formatted as string ...
     // Check and convert it!
     sal_uInt16 nCode = 0;
     if (!KeyMapping::impl_st_interpretIdentifierAsPureKeyCode(sIdentifier, nCode))
diff --git a/framework/source/fwi/classes/converter.cxx b/framework/source/fwi/classes/converter.cxx
index 330eb38..4dfe070 100644
--- a/framework/source/fwi/classes/converter.cxx
+++ b/framework/source/fwi/classes/converter.cxx
@@ -65,7 +65,7 @@ OUString Converter::convert_DateTime2ISO8601( const DateTime& aSource )
     sal_Int32 nMin   = aSource.GetMin();
     sal_Int32 nSec   = aSource.GetSec();
 
-    // write year formated as "YYYY"
+    // write year formatted as "YYYY"
     if (nYear<10)
         sBuffer.appendAscii("000");
     else if (nYear<100)
@@ -75,31 +75,31 @@ OUString Converter::convert_DateTime2ISO8601( const DateTime& aSource )
     sBuffer.append( (sal_Int32)nYear );
 
     sBuffer.appendAscii("-");
-    // write month formated as "MM"
+    // write month formatted as "MM"
     if (nMonth<10)
         sBuffer.appendAscii("0");
     sBuffer.append( (sal_Int32)nMonth );
 
     sBuffer.appendAscii("-");
-    // write day formated as "DD"
+    // write day formatted as "DD"
     if (nDay<10)
         sBuffer.appendAscii("0");
     sBuffer.append( (sal_Int32)nDay );
 
     sBuffer.appendAscii("T");
-    // write hours formated as "hh"
+    // write hours formatted as "hh"
     if (nHour<10)
         sBuffer.appendAscii("0");
     sBuffer.append( (sal_Int32)nHour );
 
     sBuffer.appendAscii(":");
-    // write min formated as "mm"
+    // write min formatted as "mm"
     if (nMin<10)
         sBuffer.appendAscii("0");
     sBuffer.append( (sal_Int32)nMin );
 
     sBuffer.appendAscii(":");
-    // write sec formated as "ss"
+    // write sec formatted as "ss"
     if (nSec<10)
         sBuffer.appendAscii("0");
     sBuffer.append( (sal_Int32)nSec );
diff --git a/framework/source/jobs/jobdata.cxx b/framework/source/jobs/jobdata.cxx
index 814da4a..3c0adc8 100644
--- a/framework/source/jobs/jobdata.cxx
+++ b/framework/source/jobs/jobdata.cxx
@@ -457,7 +457,7 @@ bool isEnabled( const OUString& sAdminTime ,
     bool bValidUser  = aISOPattern.Matches(sUserTime );
 
     // We check for "isEnabled()" here only.
-    // Note further: ISO8601 formated strings can be compared as strings directly!
+    // Note further: ISO8601 formatted strings can be compared as strings directly!
     //               FIXME: this is not true! "T1215" is the same time as "T12:15" or "T121500"
     return (
             (!bValidAdmin && !bValidUser                         ) ||
diff --git a/framework/source/jobs/joburl.cxx b/framework/source/jobs/joburl.cxx
index 54e69f3..0eb7d17 100644
--- a/framework/source/jobs/joburl.cxx
+++ b/framework/source/jobs/joburl.cxx
@@ -513,7 +513,7 @@ void JobURL::impldbg_checkURL( /*IN*/ const sal_Char*  pURL                 ,
     @descr      It returns a representation of the internal object state
                 as string notation.
 
-    @returns    The formated string representation.
+    @returns    The formatted string representation.
 */
 OUString JobURL::impldbg_toString() const
 {
diff --git a/framework/source/xml/acceleratorconfigurationreader.cxx b/framework/source/xml/acceleratorconfigurationreader.cxx
index 346d84a..7e768f9 100644
--- a/framework/source/xml/acceleratorconfigurationreader.cxx
+++ b/framework/source/xml/acceleratorconfigurationreader.cxx
@@ -32,7 +32,7 @@
 
 namespace framework{
 
-/* Throws a SaxException in case a wrong formated XML
+/* Throws a SaxException in case a wrong formatted XML
    structure was detected.
 
    This macro combined the given comment with a generic
diff --git a/include/basic/sbxform.hxx b/include/basic/sbxform.hxx
index 71ed5ab..4a2f044 100644
--- a/include/basic/sbxform.hxx
+++ b/include/basic/sbxform.hxx
@@ -96,7 +96,7 @@ class BASIC_DLLPUBLIC SbxBasicFormater {
     /* Basic command: Format$( number,format-string )
 
        Parameter:
-        dNumber     : number to be formated
+        dNumber     : number to be formatted
         sFormatStrg : the Format-String, e.g. ###0.0###
 
        Return value:
diff --git a/include/svx/DescriptionGenerator.hxx b/include/svx/DescriptionGenerator.hxx
index 0cf5593..f8fc1cb 100644
--- a/include/svx/DescriptionGenerator.hxx
+++ b/include/svx/DescriptionGenerator.hxx
@@ -163,24 +163,24 @@ private:
     */
     bool mbIsFirstProperty;
 
-    /** Add a property value formated as color to the description string.
+    /** Add a property value formatted as color to the description string.
     */
     SVX_DLLPRIVATE void AddColor (const OUString& sPropertyName,
         const OUString& sLocalizedName);
 
-    /** Add a property value formated as integer to the description string.
+    /** Add a property value formatted as integer to the description string.
     */
     SVX_DLLPRIVATE void AddInteger (const OUString& sPropertyName,
         const OUString& sLocalizedName);
 
-    /** Add a property value formated as string to the description string.
+    /** Add a property value formatted as string to the description string.
         @param sPropertyName
             Name of the property.
     */
     SVX_DLLPRIVATE void AddString (const OUString& sPropertyName,
         const OUString& sLocalizedName, long nWhichId = -1);
 
-    /** Add a property value formated as fill style to the description
+    /** Add a property value formatted as fill style to the description
         string.  If the fill style is <const>HATCH</const>,
         <const>GRADIENT</const>, or <const>BITMAP</const>, then the of the
         hatch, gradient, or bitmap is appended as well.
diff --git a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/FunctionHelper.java b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/FunctionHelper.java
index 9d9116c..0aa3fde 100644
--- a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/FunctionHelper.java
+++ b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/FunctionHelper.java
@@ -64,7 +64,7 @@ public class FunctionHelper
 
 
     /**
-     * This convert an URL (formated as a string) to a struct com.sun.star.util.URL.
+     * This convert an URL (formatted as a string) to a struct com.sun.star.util.URL.
      * It use a special service to do that: the URLTransformer.
      * Because some API calls need it and it's not allowed to set "Complete"
      * part of the util struct only. The URL must be parsed.
diff --git a/offapi/com/sun/star/text/DateDisplayFormat.idl b/offapi/com/sun/star/text/DateDisplayFormat.idl
index 16437a9..ce314a8 100644
--- a/offapi/com/sun/star/text/DateDisplayFormat.idl
+++ b/offapi/com/sun/star/text/DateDisplayFormat.idl
@@ -24,7 +24,7 @@
  module com {  module sun {  module star {  module text {
 
 
-/** This constants define how a date field is formated before it is displayed.
+/** This constants define how a date field is formatted before it is displayed.
     The format may also depend on the system or document locale. The samples
     are in German.
 
diff --git a/offapi/com/sun/star/text/TimeDisplayFormat.idl b/offapi/com/sun/star/text/TimeDisplayFormat.idl
index 0abd6fa..986ed35 100644
--- a/offapi/com/sun/star/text/TimeDisplayFormat.idl
+++ b/offapi/com/sun/star/text/TimeDisplayFormat.idl
@@ -24,7 +24,7 @@
  module com {  module sun {  module star {  module text {
 
 
-/** This constants define how a time field is formated before it is displayed.
+/** This constants define how a time field is formatted before it is displayed.
     The formate may also depend on the system or document locale.
 
     @deprecated
diff --git a/offapi/com/sun/star/text/textfield/URL.idl b/offapi/com/sun/star/text/textfield/URL.idl
index 30fbdf2..a6edcdf 100644
--- a/offapi/com/sun/star/text/textfield/URL.idl
+++ b/offapi/com/sun/star/text/textfield/URL.idl
@@ -33,7 +33,7 @@ published service URL
 {
     service  com::sun::star::text::TextField;
 
-    /** Specifies how the URL is formated on output.
+    /** Specifies how the URL is formatted on output.
     */
     [property] short Format;
 
diff --git a/sd/source/ui/app/sdmod2.cxx b/sd/source/ui/app/sdmod2.cxx
index fc01b4a..fa5f4a0 100644
--- a/sd/source/ui/app/sdmod2.cxx
+++ b/sd/source/ui/app/sdmod2.cxx
@@ -119,7 +119,7 @@ static SdPage* GetCurrentPage( sd::ViewShell* pViewSh, EditFieldInfo* pInfo, boo
         // which all use the new possibility of setting the visualized page at the SdrOutliner.
 
         // if all else failed, geht the current page from the object that is
-        // currently formated from the document
+        // currently formatted from the document
         if(!pPage)
         {
             const SdrTextObj* pTextObj = (pViewSh && pViewSh->GetDoc()) ? pViewSh->GetDoc()->GetFormattingTextObj() : NULL;
diff --git a/sd/source/ui/inc/taskpane/TaskPaneTreeNode.hxx b/sd/source/ui/inc/taskpane/TaskPaneTreeNode.hxx
index 5c1111f..34b9214 100644
--- a/sd/source/ui/inc/taskpane/TaskPaneTreeNode.hxx
+++ b/sd/source/ui/inc/taskpane/TaskPaneTreeNode.hxx
@@ -150,7 +150,7 @@ public:
             const ::com::sun::star::uno::Reference<
             ::com::sun::star::accessibility::XAccessible>&rxParent);
 
-    /** Add a listener that will be informated in the future about state
+    /** Add a listener that will be informatted in the future about state
         changes of the tree node.  This includes adding and removing
         children as well as focus, visibility, and expansion state.
         Multiple calls are ignored.  Each listener is added only once.
diff --git a/sfx2/source/bastyp/fltfnc.cxx b/sfx2/source/bastyp/fltfnc.cxx
index e759875e..ee4a7fb 100644
--- a/sfx2/source/bastyp/fltfnc.cxx
+++ b/sfx2/source/bastyp/fltfnc.cxx
@@ -919,7 +919,7 @@ const SfxFilter* SfxFilterMatcherIter::Next()
 }
 
 /*---------------------------------------------------------------
-    helper to build own formated string from given stringlist by
+    helper to build own formatted string from given stringlist by
     using given separator
   ---------------------------------------------------------------*/
 OUString implc_convertStringlistToString( const uno::Sequence< OUString >& lList     ,
diff --git a/shell/source/win32/shlxthandler/infotips/infotips.cxx b/shell/source/win32/shlxthandler/infotips/infotips.cxx
index 8686898..abfb8d6 100644
--- a/shell/source/win32/shlxthandler/infotips/infotips.cxx
+++ b/shell/source/win32/shlxthandler/infotips/infotips.cxx
@@ -255,7 +255,7 @@ HRESULT STDMETHODCALLTYPE CInfoTip::GetInfoTip(DWORD /*dwFlags*/, wchar_t** ppws
             msg += meta_info_accessor.getTagData( META_INFO_DESCRIPTION );
         }
 
-        //display midified time formated into locale representation.
+        //display midified time formatted into locale representation.
         if ( iso8601_date_to_local_date(meta_info_accessor.getTagData(META_INFO_MODIFIED )).length() > 0)
         {
             if ( msg != EMPTY_STRING )
diff --git a/starmath/inc/cursor.hxx b/starmath/inc/cursor.hxx
index 6a523cf..441a733 100644
--- a/starmath/inc/cursor.hxx
+++ b/starmath/inc/cursor.hxx
@@ -144,7 +144,7 @@ public:
     /** Insert a special node created from aString
      *
      * Used for handling insert request from the "catalog" dialog.
-     * The provided string should be formated as the desired command: %phi
+     * The provided string should be formatted as the desired command: %phi
      * Note: this method ONLY supports commands defined in Math.xcu
      *
      * For more complex expressions use InsertCommandText, this method doesn't
diff --git a/svtools/source/control/fmtfield.cxx b/svtools/source/control/fmtfield.cxx
index a3dec60..1b43103 100644
--- a/svtools/source/control/fmtfield.cxx
+++ b/svtools/source/control/fmtfield.cxx
@@ -924,7 +924,7 @@ bool FormattedField::ImplGetValue(double& dNewVal)
     sal_uInt32 nFormatKey = m_nFormatKey; // IsNumberFormat changes the FormatKey!
 
     if (ImplGetFormatter()->IsTextFormat(nFormatKey) && m_bTreatAsNumber)
-        // for detection of values like "1,1" in fields that are formated as text
+        // for detection of values like "1,1" in fields that are formatted as text
         nFormatKey = 0;
 
     // special treatment for percentage formatting
diff --git a/svx/source/svdraw/svdotextdecomposition.cxx b/svx/source/svdraw/svdotextdecomposition.cxx
index 60302d2..8041b3d 100644
--- a/svx/source/svdraw/svdotextdecomposition.cxx
+++ b/svx/source/svdraw/svdotextdecomposition.cxx
@@ -928,7 +928,7 @@ void SdrTextObj::impDecomposeBlockTextPrimitive(
 
     if(bIsCell)
     {
-        // cell text is formated neither like a text object nor like a object
+        // cell text is formatted neither like a text object nor like a object
         // text, so use a special setup here
         rOutliner.SetMaxAutoPaperSize(aAnchorTextSize);
 
diff --git a/sw/inc/IDocumentContentOperations.hxx b/sw/inc/IDocumentContentOperations.hxx
index 39f9265..38c900a 100644
--- a/sw/inc/IDocumentContentOperations.hxx
+++ b/sw/inc/IDocumentContentOperations.hxx
@@ -188,11 +188,11 @@ public:
         attribute is split, provided it makes sense.
         Nodes, where this attribute does not make sense are ignored.
         In nodes completely enclosed in the selection the attribute
-        becomes hard-formated, in all other (text-) nodes the attribute
+        becomes hard-formatted, in all other (text-) nodes the attribute
         is inserted into the attribute array.
         For a character attribute, in cases where no selection exists
         an "empty" hint is inserted. If there is a selection the attribute
-        is hard-formated and added to the node at rRg.Start().
+        is hard-formatted and added to the node at rRg.Start().
         If the attribute could not be inserted, the method returns
         false.
     */
diff --git a/sw/inc/dbfld.hxx b/sw/inc/dbfld.hxx
index 9ee797c..7df97ef 100644
--- a/sw/inc/dbfld.hxx
+++ b/sw/inc/dbfld.hxx
@@ -54,7 +54,7 @@ public:
 };
 
 // Classes derived from SwFields. They overlay the expand-function.
-// Content is formated according to the format (if available).
+// Content is formatted according to the format (if available).
 class SW_DLLPUBLIC SwDBField : public SwValueField
 {
     OUString aContent;
diff --git a/sw/inc/doc.hxx b/sw/inc/doc.hxx
index 20044942..a096bbe 100644
--- a/sw/inc/doc.hxx
+++ b/sw/inc/doc.hxx
@@ -759,7 +759,7 @@ public:
     void SetAllUniqueFlyNames();
 
     /** Reset attributes. All TxtHints and (if completely selected) all hard-
-     formated stuff (auto-formats) are removed.
+     formatted stuff (auto-formats) are removed.
      Introduce new optional parameter <bSendDataChangedEvents> in order to
      control, if the side effect "send data changed events" is triggered or not. */
     void ResetAttrs( const SwPaM &rRg,
diff --git a/sw/inc/fesh.hxx b/sw/inc/fesh.hxx
index 03aca2b..13587c6 100644
--- a/sw/inc/fesh.hxx
+++ b/sw/inc/fesh.hxx
@@ -121,7 +121,7 @@ enum ObjCntType
 enum CurRectType
 {
     RECT_PAGE,                  ///< Rect of current page.
-    RECT_PAGE_CALC,             ///< ... page will be formated if required.
+    RECT_PAGE_CALC,             ///< ... page will be formatted if required.
     RECT_PAGE_PRT,              ///< Rect of current PrtArea of page.
     RECT_FRM,                   ///< Rect of current frame.
     RECT_FLY_EMBEDDED,          ///< Rect of current FlyFrm.
diff --git a/sw/inc/fldbas.hxx b/sw/inc/fldbas.hxx
index 993abd1..b43e4f9 100644
--- a/sw/inc/fldbas.hxx
+++ b/sw/inc/fldbas.hxx
@@ -378,7 +378,7 @@ inline sal_uInt32 SwField::GetFormat() const
 inline sal_uInt16 SwField::GetLanguage() const
     { return nLang;     }
 
- /// Fields containing values that have to be formated via number formatter.
+ /// Fields containing values that have to be formatted via number formatter.
 class SwValueFieldType : public SwFieldType
 {
     SwDoc*  pDoc;
diff --git a/sw/inc/node.hxx b/sw/inc/node.hxx
index 4013b25..4537fde 100644
--- a/sw/inc/node.hxx
+++ b/sw/inc/node.hxx
@@ -262,7 +262,7 @@ public:
         table cells ... including anchor in case of frames or footnotes)? */
     bool IsProtect() const;
 
-    /** Search PageDesc with which this node is formated. If layout is existent
+    /** Search PageDesc with which this node is formatted. If layout is existent
        search over layout, else only the hard way is left: search over the nodes
        to the front!! */
     const SwPageDesc* FindPageDesc( bool bCalcLay, sal_uInt32* pPgDescNdIdx = 0 ) const;
diff --git a/sw/inc/swtable.hxx b/sw/inc/swtable.hxx
index 751f528..f20b885 100644
--- a/sw/inc/swtable.hxx
+++ b/sw/inc/swtable.hxx
@@ -436,7 +436,7 @@ public:
 
     bool IsInHeadline( const SwTable* pTbl = 0 ) const;
 
-    // Contains box contents, that can be formated as a number?
+    // Contains box contents, that can be formatted as a number?
     bool HasNumCntnt( double& rNum, sal_uInt32& rFmtIndex,
                     bool& rIsEmptyTxtNd ) const;
     sal_uLong IsValidNumTxtNd( bool bCheckAttr = true ) const;
diff --git a/sw/source/core/layout/trvlfrm.cxx b/sw/source/core/layout/trvlfrm.cxx
index 0598e58..3382325 100644
--- a/sw/source/core/layout/trvlfrm.cxx
+++ b/sw/source/core/layout/trvlfrm.cxx
@@ -1446,7 +1446,7 @@ void SwPageFrm::GetCntntPosition( const Point &rPt, SwPosition &rPos ) const
 
     if( !pAct->IsValid() )
     {
-        // CntntFrm not formated -> always on node-beginning
+        // CntntFrm not formatted -> always on node-beginning
         SwCntntNode* pCNd = (SwCntntNode*)pAct->GetNode();
         OSL_ENSURE( pCNd, "Where is my CntntNode?" );
         rPos.nNode = *pCNd;
diff --git a/sw/source/core/text/widorp.cxx b/sw/source/core/text/widorp.cxx
index 89ad398..305c6dd 100644
--- a/sw/source/core/text/widorp.cxx
+++ b/sw/source/core/text/widorp.cxx
@@ -99,7 +99,7 @@ SwTxtFrmBreak::SwTxtFrmBreak( SwTxtFrm *pNewFrm, const SwTwips nRst )
  * Master- and Follow-Frame:
  * Example: If the first column is 3cm and the second is 4cm and
  * Widows is set to 3, the decision if the Widows rule matches can not
- * be done until the Follow is formated. Unfortunately this is crucial
+ * be done until the Follow is formatted. Unfortunately this is crucial
  * to decide if the whole paragraph goes to the next page or not.
  */
 bool SwTxtFrmBreak::IsInside( SwTxtMargin &rLine ) const
diff --git a/sw/source/filter/ww8/ww8par3.cxx b/sw/source/filter/ww8/ww8par3.cxx
index f8145e2..f085e7f 100644
--- a/sw/source/filter/ww8/ww8par3.cxx
+++ b/sw/source/filter/ww8/ww8par3.cxx
@@ -2003,7 +2003,7 @@ void SwWW8ImplReader::Read_LFOPosition(sal_uInt16, const sal_uInt8* pData,
             }
             else if (SwTxtNode* pTxtNode = pPaM->GetNode().GetTxtNode())
             {
-                // here a paragraph is being directly formated
+                // here a paragraph is being directly formatted
 
                 // empty the numbering/list style applied to the current paragraph
                 SwNumRuleItem aEmptyRule( aEmptyOUStr );
diff --git a/swext/mediawiki/src/filter/odt2mediawiki.xsl b/swext/mediawiki/src/filter/odt2mediawiki.xsl
index 1205536..89fecbc 100644
--- a/swext/mediawiki/src/filter/odt2mediawiki.xsl
+++ b/swext/mediawiki/src/filter/odt2mediawiki.xsl
@@ -481,7 +481,7 @@
 	 -->
 
     <!--
-       Make sure to join sibling node that are all formated with WikiMath style without repeating
+       Make sure to join sibling node that are all formatted with WikiMath style without repeating
        the <math>..</math> markup.
 
        Do not apply any transformation to the contents marked as WikiMath.
diff --git a/vcl/source/edit/textdata.cxx b/vcl/source/edit/textdata.cxx
index 00f5b73..3e1df3e 100644
--- a/vcl/source/edit/textdata.cxx
+++ b/vcl/source/edit/textdata.cxx
@@ -189,8 +189,8 @@ void TEParaPortion::CorrectValuesBehindLastFormattedLine( sal_uInt16 nLastFormat
         short nTextDiff = pUnformatted.GetStart() - pLastFormatted.GetEnd();
         nTextDiff++;    // LastFormatted.GetEnd() was inclusive => subtracted one too much!
 
-        // The first unformated one has to start exactly one portion past the last
-        // formated one.
+        // The first unformatted one has to start exactly one portion past the last
+        // formatted one.
         // If a portion got split in the changed row, nLastEnd could be > nNextStart!
         short nPDiff = sal::static_int_cast< short >(-( nPortionDiff-1 ));
         short nTDiff = sal::static_int_cast< short >(-( nTextDiff-1 ));
diff --git a/vcl/source/filter/sgvtext.cxx b/vcl/source/filter/sgvtext.cxx
index a069259..2a01dbc 100644
--- a/vcl/source/filter/sgvtext.cxx
+++ b/vcl/source/filter/sgvtext.cxx
@@ -150,7 +150,7 @@ extern SgfFontLst* pSgfFonts;
 #define  THJustCenter   0x01
 #define  THJustRight    0x02
 #define  THJustBlock    0x03
-#define  THJustDrvOut   0x04   /* Justified         formated */
+#define  THJustDrvOut   0x04   /* Justified         formatted */
 #define  THJustLocked   0x05   /* J u s t   l  o  c  k  e  d */
 
 #define  MaxCharSlant   4200   /* maximum 42deg italic ! */
commit 5584d73f2db413889347b4b3a1fcaf124db02b21
Author: Julien Nabet <serval2412 at yahoo.fr>
Date:   Wed Mar 25 20:41:42 2015 +0100

    Typos
    
    Change-Id: I434be0034b26ac4719590238817538ecd90b8923

diff --git a/chart2/source/tools/InternalDataProvider.cxx b/chart2/source/tools/InternalDataProvider.cxx
index db8f2da..0a369a3 100644
--- a/chart2/source/tools/InternalDataProvider.cxx
+++ b/chart2/source/tools/InternalDataProvider.cxx
@@ -814,7 +814,7 @@ Reference< chart2::data::XDataSequence > SAL_CALL InternalDataProvider::createDa
 {
     if( aRangeRepresentation.match( lcl_aCategoriesRangeName ))
     {
-        OSL_ASSERT( aRangeRepresentation == lcl_aCategoriesRangeName );//it is not expected nor implmented that only parts of the categories are really requested
+        OSL_ASSERT( aRangeRepresentation == lcl_aCategoriesRangeName );//it is not expected nor implemented that only parts of the categories are really requested
 
         // categories
         return createDataSequenceAndAddToMap( lcl_aCategoriesRangeName, lcl_aCategoriesRoleName );
@@ -864,7 +864,7 @@ sal_Bool SAL_CALL InternalDataProvider::hasDataByRangeRepresentation( const OUSt
 
     if( aRange.match( lcl_aCategoriesRangeName ))
     {
-        OSL_ASSERT( aRange == lcl_aCategoriesRangeName );//it is not expected nor implmented that only parts of the categories are really requested
+        OSL_ASSERT( aRange == lcl_aCategoriesRangeName );//it is not expected nor implemented that only parts of the categories are really requested
         bResult = true;
     }
     else if( aRange.match( lcl_aLabelRangePrefix ))
@@ -1186,7 +1186,7 @@ OUString SAL_CALL InternalDataProvider::convertRangeToXML( const OUString& aRang
     // @todo: add this information in the range representation strings
     if( aRangeRepresentation.match( lcl_aCategoriesRangeName ))
     {
-        OSL_ASSERT( aRangeRepresentation == lcl_aCategoriesRangeName );//it is not expected nor implmented that only parts of the categories are really requested
+        OSL_ASSERT( aRangeRepresentation == lcl_aCategoriesRangeName );//it is not expected nor implemented that only parts of the categories are really requested
         aRange.aUpperLeft.bIsEmpty = false;
         if( m_bDataInColumns )
         {
diff --git a/filter/qa/complex/filter/misc/FinalizedMandatoryTest.java b/filter/qa/complex/filter/misc/FinalizedMandatoryTest.java
index f0c04b6..1e43393 100644
--- a/filter/qa/complex/filter/misc/FinalizedMandatoryTest.java
+++ b/filter/qa/complex/filter/misc/FinalizedMandatoryTest.java
@@ -270,7 +270,7 @@ public class FinalizedMandatoryTest
     }
 
     /**
-     * print all propeties with its values to <CODE>logger</CODE>. For debug purposes.
+     * print all properties with its values to <CODE>logger</CODE>. For debug purposes.
      * @see stats.SimpleLogWriter
      * @see com.sun.star.beans.PropertyValue
      * @param props Sequenze of PropertyValue
diff --git a/filter/source/xslt/import/uof/uof2odf_spreadsheet.xsl b/filter/source/xslt/import/uof/uof2odf_spreadsheet.xsl
index 00143a2..0cc023d 100644
--- a/filter/source/xslt/import/uof/uof2odf_spreadsheet.xsl
+++ b/filter/source/xslt/import/uof/uof2odf_spreadsheet.xsl
@@ -7752,8 +7752,8 @@
 		<xsl:param name="series-generate-type"/>
 		<xsl:for-each select="表:数据系列">
 			<style:style style:family="chart">
-				<xsl:variable name="current-positon" select="position()"/>
-				<xsl:attribute name="style:name"><xsl:value-of select="concat('data-series',$current-positon)"/></xsl:attribute>
+				<xsl:variable name="current-position" select="position()"/>
+				<xsl:attribute name="style:name"><xsl:value-of select="concat('data-series',$current-position)"/></xsl:attribute>
 				<xsl:call-template name="表:数据点类型">
 					<xsl:with-param name="table-name" select="$table-name"/>
 					<xsl:with-param name="table-type" select="$table-type"/>
@@ -7824,8 +7824,8 @@
 		<xsl:param name="series-generate-type"/>
 		<xsl:for-each select="表:系列">
 			<style:style style:family="chart">
-				<xsl:variable name="current-positon" select="position()"/>
-				<xsl:attribute name="style:name"><xsl:value-of select="concat('data-source',$current-positon)"/></xsl:attribute>
+				<xsl:variable name="current-position" select="position()"/>
+				<xsl:attribute name="style:name"><xsl:value-of select="concat('data-source',$current-position)"/></xsl:attribute>
 			</style:style>
 		</xsl:for-each>
 	</xsl:template>
diff --git a/fpicker/source/win32/filepicker/PreviewCtrl.hxx b/fpicker/source/win32/filepicker/PreviewCtrl.hxx
index 0b4db89..ad63f7c 100644
--- a/fpicker/source/win32/filepicker/PreviewCtrl.hxx
+++ b/fpicker/source/win32/filepicker/PreviewCtrl.hxx
@@ -85,7 +85,7 @@ public:
 // A simple file preview class to preview some
 // common picture formats like *.gif, *jpg, etc.
 // This class is not thread-safe and is
-// implmented as singleton, because the class
+// implemented as singleton, because the class
 // has only one static member to reconnect
 // from callback functions
 // we use a singleton-destroyer to get rid off
diff --git a/include/registry/types.h b/include/registry/types.h
index e51d05f..e28d7db 100644
--- a/include/registry/types.h
+++ b/include/registry/types.h
@@ -112,7 +112,7 @@ enum RTTypeClass {
 /** specifies the type for the field access.
 
     Fields in a type blob are used for different types.  Among others they were
-    used for properties of services and these poperties can have several flags.
+    used for properties of services and these properties can have several flags.
 
     @see RT_ACCESS_INVALID
     @see RT_ACCESS_READONLY
diff --git a/offapi/type_reference/typelibrary_history.txt b/offapi/type_reference/typelibrary_history.txt
index 7bc723f..0a2e288 100644
--- a/offapi/type_reference/typelibrary_history.txt
+++ b/offapi/type_reference/typelibrary_history.txt
@@ -42,8 +42,8 @@
   the cli interfaces from type library.
 
 11/19/2004 (JSC/TL): BugID=i36687
-  adjust ChainedTextFrame service. Remove XChainable interface and insert propeties.
-  Interface was never implmented and the functionality was supported by properties.
+  adjust ChainedTextFrame service. Remove XChainable interface and insert properties.
+  Interface was never implemented and the functionality was supported by properties.
 
 01/20/2005 (JSC): BugID=i40985
   change const value com.sun.star.configuration.backend.NodeAttribute:MASK to
diff --git a/qadevOOo/tests/java/ifc/inspection/_XObjectInspectorModel.java b/qadevOOo/tests/java/ifc/inspection/_XObjectInspectorModel.java
index 08b868d..14fa235 100644
--- a/qadevOOo/tests/java/ifc/inspection/_XObjectInspectorModel.java
+++ b/qadevOOo/tests/java/ifc/inspection/_XObjectInspectorModel.java
@@ -54,7 +54,7 @@ public class _XObjectInspectorModel extends MultiMethodTest {
     }
 
     /**
-     * Call the method <CODE>getPropertyOrderIndex()</CODE> with an invalid propety name.
+     * Call the method <CODE>getPropertyOrderIndex()</CODE> with an invalid property name.
      * Has <CODE>OK</CODE> status if the returned index is "0".
      */
     public void _getPropertyOrderIndex() {
diff --git a/qadevOOo/tests/java/ifc/style/_CharacterProperties.java b/qadevOOo/tests/java/ifc/style/_CharacterProperties.java
index 6e96833..b2c51a8 100644
--- a/qadevOOo/tests/java/ifc/style/_CharacterProperties.java
+++ b/qadevOOo/tests/java/ifc/style/_CharacterProperties.java
@@ -340,7 +340,7 @@ public class _CharacterProperties extends MultiPropertyTest {
      * changed and set.
      * @param get PropertySet where property value is checked after
      * setting.
-     * @param name Propety name to test.
+     * @param name Property name to test.
      * @param newVal Value used to set as new property value if
      * the value get is null.
      */
diff --git a/sc/source/ui/view/viewdata.cxx b/sc/source/ui/view/viewdata.cxx
index 3d2f772..45e0165 100644
--- a/sc/source/ui/view/viewdata.cxx
+++ b/sc/source/ui/view/viewdata.cxx
@@ -990,7 +990,7 @@ void ScViewData::SetEditEngine( ScSplitPos eWhich,
         nEditStartCol = nEditCol;
 
         //  For growing use only the alignment value from the attribute, numbers
-        //  (existing or started) with default aligment extend to the right.
+        //  (existing or started) with default alignment extend to the right.
         bool bGrowCentered = ( eJust == SVX_HOR_JUSTIFY_CENTER );
         bool bGrowToLeft = ( eJust == SVX_HOR_JUSTIFY_RIGHT );      // visual left
         bool bGrowBackwards = bGrowToLeft;                          // logical left
diff --git a/scripting/examples/java/Newsgroup/PostNewsgroup.java b/scripting/examples/java/Newsgroup/PostNewsgroup.java
index f8320f4..8c76331 100644
--- a/scripting/examples/java/Newsgroup/PostNewsgroup.java
+++ b/scripting/examples/java/Newsgroup/PostNewsgroup.java
@@ -599,7 +599,7 @@ public class PostNewsgroup extends JFrame {
 
         // replyTextField must have <string>@<string>.<string>
         // (string at least 2 chars long)
-        // consider <s>.<s>@<s>.<s>.<s> format? (array of dot positons?)
+        // consider <s>.<s>@<s>.<s>.<s> format? (array of dot positions?)
         String replyString = replyTextField.getText();
         int atPos = replyString.indexOf("@");
         int dotPos = replyString.lastIndexOf(".");
diff --git a/svgio/source/svgreader/svgtextpathnode.cxx b/svgio/source/svgreader/svgtextpathnode.cxx
index a737426..cc2a576 100644
--- a/svgio/source/svgreader/svgtextpathnode.cxx
+++ b/svgio/source/svgreader/svgtextpathnode.cxx
@@ -166,7 +166,7 @@ namespace svgio
                         // create representation for this snippet
                         bRetval = true;
 
-                        // get target position and tangent in that pint
+                        // get target position and tangent in that point
                         basegfx::B2DPoint aPosition(0.0, 0.0);
                         basegfx::B2DVector aTangent(0.0, 1.0);
 
diff --git a/sw/qa/extras/tiledrendering/tiledrendering.cxx b/sw/qa/extras/tiledrendering/tiledrendering.cxx
index f88c465..3aa33b2 100644
--- a/sw/qa/extras/tiledrendering/tiledrendering.cxx
+++ b/sw/qa/extras/tiledrendering/tiledrendering.cxx
@@ -83,7 +83,7 @@ void SwTiledRenderingTest::testRegisterCallback()
     SwXTextDocument* pXTextDocument = createDoc("dummy.fodt");
     pXTextDocument->registerCallback(&SwTiledRenderingTest::callback, this);
     SwWrtShell* pWrtShell = pXTextDocument->GetDocShell()->GetWrtShell();
-    // Insert a character at the begining of the document.
+    // Insert a character at the beginning of the document.
     pWrtShell->Insert("x");
 
     // Check that the top left 256x256px tile would be invalidated.
diff --git a/sw/source/core/crsr/crsrsh.cxx b/sw/source/core/crsr/crsrsh.cxx
index 19b7861..c3df6f4 100644
--- a/sw/source/core/crsr/crsrsh.cxx
+++ b/sw/source/core/crsr/crsrsh.cxx
@@ -3451,7 +3451,7 @@ void SwCrsrShell::GetSmartTagTerm( const Point& rPt, SwRect& rSelectRect,
             // get smarttag word
             OUString aText( pNode->GetTxt().copy(nBegin, nLen) );
 
-            //save the start and end positons of the line and the starting point
+            //save the start and end positions of the line and the starting point
             Push();
             LeftMargin();
             const sal_Int32 nLineStart = GetCrsr()->GetPoint()->nContent.GetIndex();
diff --git a/sw/source/core/edit/edlingu.cxx b/sw/source/core/edit/edlingu.cxx
index 9263327..5cd956d 100644
--- a/sw/source/core/edit/edlingu.cxx
+++ b/sw/source/core/edit/edlingu.cxx
@@ -873,7 +873,7 @@ uno::Reference< XSpellAlternatives >
 
             if ( xSpellAlt.is() )   // error found?
             {
-                // save the start and end positons of the line and the starting point
+                // save the start and end positions of the line and the starting point
                 Push();
                 LeftMargin();
                 const sal_Int32 nLineStart = GetCrsr()->GetPoint()->nContent.GetIndex();
@@ -997,7 +997,7 @@ bool SwEditShell::GetGrammarCorrection(
 
             if (rResult.aErrors.getLength() > 0)    // error found?
             {
-                // save the start and end positons of the line and the starting point
+                // save the start and end positions of the line and the starting point
                 Push();
                 LeftMargin();
                 const sal_Int32 nLineStart = GetCrsr()->GetPoint()->nContent.GetIndex();
diff --git a/test/source/sheet/xnamedrange.cxx b/test/source/sheet/xnamedrange.cxx
index 2fc13f5..1ce6d98 100644
--- a/test/source/sheet/xnamedrange.cxx
+++ b/test/source/sheet/xnamedrange.cxx
@@ -106,7 +106,7 @@ void XNamedRange::testGetReferencePosition()
     uno::Reference< sheet::XNamedRange > xNamedRange = getNamedRange(aTestedNamedRangeString);
 
     table::CellAddress xCellAddress = xNamedRange->getReferencePosition();
-    // the expeted address is on B1, as it was the active cell when intial2 created
+    // the expected address is on B1, as it was the active cell when intial2 created
     CPPUNIT_ASSERT_MESSAGE("Wrong SHEET reference position", xCellAddress.Sheet == 0);
     CPPUNIT_ASSERT_MESSAGE("Wrong COLUMN reference position", xCellAddress.Column == 1);
     CPPUNIT_ASSERT_MESSAGE("Wrong ROW reference position", xCellAddress.Row == 0);
diff --git a/vcl/source/app/scheduler.cxx b/vcl/source/app/scheduler.cxx
index 8162332..a213fe2 100644
--- a/vcl/source/app/scheduler.cxx
+++ b/vcl/source/app/scheduler.cxx
@@ -170,7 +170,7 @@ void Scheduler::ProcessTaskScheduling( bool bTimer )
 
 sal_uInt64 Scheduler::UpdateMinPeriod( sal_uInt64 nMinPeriod, sal_uInt64 nTime )
 {
-    // this period is only usefull for timer
+    // this period is only useful for timer
     // so in this implementation it' only a pass through
     (void)nTime;
     return nMinPeriod;
diff --git a/writerfilter/source/dmapper/StyleSheetTable.cxx b/writerfilter/source/dmapper/StyleSheetTable.cxx
index 087425c..f50b2e8 100644
--- a/writerfilter/source/dmapper/StyleSheetTable.cxx
+++ b/writerfilter/source/dmapper/StyleSheetTable.cxx
@@ -1080,7 +1080,7 @@ void StyleSheetTable::ApplyStyleSheets( FontTablePtr rFontTable )
 
                         // Left-to-right direction if not already set
                         pEntry->pProperties->Insert(PROP_WRITING_MODE, uno::makeAny( sal_Int16(text::WritingMode_LR_TB) ), false);
-                        // Left aligment if not already set
+                        // Left alignment if not already set
                         pEntry->pProperties->Insert(PROP_PARA_ADJUST, uno::makeAny( sal_Int16(style::ParagraphAdjust_LEFT) ), false);
                     }
 


More information about the Libreoffice-commits mailing list
diff --git a/odk/examples/java/Text/HardFormatting.java b/odk/examples/java/Text/HardFormatting.java
index 559c9b9..4b00ad3 100644
--- a/odk/examples/java/Text/HardFormatting.java
+++ b/odk/examples/java/Text/HardFormatting.java
@@ -130,7 +130,7 @@ public class HardFormatting {
                 + xPropertySet.getPropertyValue("CharWeight").toString() );
 
             // the PropertyState contains information where the attribute is set,
             // is a text part hard formated or not.
             com.sun.star.beans.XPropertyState xPropertyState = null;
             xPropertyState = UnoRuntime.queryInterface(
                 com.sun.star.beans.XPropertyState.class, xWordCursor);
@@ -175,21 +175,21 @@ public class HardFormatting {
             case com.sun.star.beans.PropertyState.DIRECT_VALUE_value:  {
                 System.out.println( "-> The selection '"
                                     + xWordCursor.getString()
-                                    + "' completely hard formated" );
+                                    + "' completely hard formatted" );
                 break;
             }
 
             case com.sun.star.beans.PropertyState.DEFAULT_VALUE_value: {
                 System.out.println( "-> The selection '"
                                     + xWordCursor.getString()
-                                    + "' isn't hard formated" );
+                                    + "' isn't hard formatted" );
                 break;
             }
 
             case com.sun.star.beans.PropertyState.AMBIGUOUS_VALUE_value: {
                 System.out.println( "-> The selection '"
                                     + xWordCursor.getString()
-                                    + "' isn't completely hard formated" );
+                                    + "' isn't completely hard formatted" );
                 break;
             }
 
@@ -130,7 +130,7 @@ public class HardFormatting {
 
             // the PropertyState contains information where the attribute is set,
-            // is a text part hard formated or not.
+            // is a text part hard formatted or not.
             com.sun.star.beans.XPropertyState xPropertyState = null;
             xPropertyState = UnoRuntime.queryInterface(